@@ -1,13 +1,13 @@
 package Elasticsearch::Role::Cxn::HTTP;
 {
-  $Elasticsearch::Role::Cxn::HTTP::VERSION = '0.71';
+  $Elasticsearch::Role::Cxn::HTTP::VERSION = '0.72';
 }
 
 use Moo::Role;
 with 'Elasticsearch::Role::Cxn';
 use URI();
 use Elasticsearch::Util qw(parse_params throw);
-use namespace::autoclean;
+use namespace::clean;
 
 has 'scheme'             => ( is => 'ro' );
 has 'is_https'           => ( is => 'ro' );
@@ -32,7 +32,7 @@ sub BUILDARGS {
 
     unless ( ref $node eq 'HASH' ) {
         unless ( $node =~ m{^http(s)?://} ) {
-            $node = ( $params->{https} ? 'https://' : 'http://' ) . $node;
+            $node = ( $params->{use_https} ? 'https://' : 'http://' ) . $node;
         }
         if ( $params->{port} && $node !~ m{//[^/]+:\d+} ) {
             $node =~ s{(//[^/]+)}{$1:$params->{port}};
@@ -49,7 +49,8 @@ sub BUILDARGS {
 
     my $host = $node->{host} || 'localhost';
     my $userinfo = $node->{userinfo} || $params->{userinfo} || '';
-    my $scheme = $node->{scheme} || ( $params->{https} ? 'https' : 'http' );
+    my $scheme
+        = $node->{scheme} || ( $params->{use_https} ? 'https' : 'http' );
     my $port
         = $node->{port}
         || $params->{port}
@@ -152,7 +153,7 @@ Elasticsearch::Role::Cxn::HTTP - Provides common functionality to HTTP Cxn imple
 
 =head1 VERSION
 
-version 0.71
+version 0.72
 
 =head1 DESCRIPTION
 
@@ -194,13 +195,13 @@ Alternatively, a C<node> can be specified as a hash:
     }
 
 Similarly, default values can be specified with C<port>, C<path_prefix>,
-C<userinfo> and C<https>:
+C<userinfo> and C<use_https>:
 
     $e = Elasticsearch->new(
         port        => 9201,
         path_prefix => '/path',
         userinfo    => 'user:pass',
-        https       => 1,
+        use_https   => 1,
         nodes       => [ 'search1', 'search2' ]
     )
 
